@@ -415,17 +415,20 @@ get_length_from_term(HippoCanvasStyle *style,
     case FONT_RELATIVE:
         {
             PangoFontDescription *desc;
+            double font_size;
             
             if (use_parent_font)
                 desc = get_parent_font(style);
             else
                 desc = hippo_canvas_style_get_font(style);
-            
+
+            font_size = (double)pango_font_description_get_size(desc) / PANGO_SCALE;
+
             if (pango_font_description_get_size_is_absolute(desc)) {
-                *length = num->val * multiplier * pango_font_description_get_size(desc);
+                *length = num->val * multiplier * font_size;
             } else {
                 double resolution = hippo_canvas_context_get_resolution(style->context);
-                *length = num->val * multiplier * (resolution / 72.) * pango_font_description_get_size(desc);
+                *length = num->val * multiplier * (resolution / 72.) * font_size;
             }
         }
         break;
